==> dl.php?src=linea21_1_4.zip: linea21/theme/quickbox.php <==
<?php
/**
 * @package linea21.core
 * @subpackage theme
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

$qbx_module = _t('menu','theme');

if ($todo == 'add') {
  $result = $sql_object->DBSelect($req_quickbox_listadd);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_theme_title = formatText(cutText($result[$i]['theme_name'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=" . $result[$i]['theme_id'] . "&amp;rub=" . $rub . "&amp;todo=det\" title=\"" . _t('divers','date_crea') . ": " . $result[$i]['theme_date_crea_display'] . " \">" . $qbx_theme_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb  . _t('theme','qb_titleadd');
}

if ($todo == 'mod' || $todo == 'list' || $todo == 'det') {
  $result = $sql_object->DBSelect($req_quickbox_listmod);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_theme_title = formatText(cutText($result[$i]['theme_name'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=" . $result[$i]['theme_id'] . "&amp;rub=" . $rub . "&amp;todo=det\" title=\"" . _t('divers','last_modify') . " " . $result[$i]['theme_last_modify_display'] . " - (" . _t('divers','date_crea') . ": " . $result[$i]['theme_date_crea_display'] . ") \">" . $qbx_theme_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('theme','qb_titlemod');
}

if ($todo == 'sup') {
  $result = $sql_object->DBSelect($req_quickbox_listsup);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_theme_title = formatText(cutText($result[$i]['theme_name'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"#\" title=\"" . _t('divers','date_sup') . " " . $result[$i]['theme_last_modify_display'] . " - (" . _t('divers','date_crea') . ": " . $result[$i]['theme_date_crea_display'] . ") \">" . $qbx_theme_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('theme','qb_titlesup');
}

echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
echo "</div>\n";

?>

==> dl.php?src=linea21_1_6.zip: linea21/theme/quickbox.php <==
<?php
/**
 * @package linea21.core
 * @subpackage theme
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

$qbx_module = _t('menu','theme');

if ($todo == 'add') {
  $result = $sql_object->DBSelect($req_quickbox_listadd);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_theme_title = formatText(cutText($result[$i]['theme_name'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=" . $result[$i]['theme_id'] . "&amp;rub=" . $rub . "&amp;todo=det\" title=\"" . _t('divers','date_crea') . ": " . $result[$i]['theme_date_crea_display'] . " \">" . $qbx_theme_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb  . _t('theme','qb_titleadd');
}

if ($todo == 'mod' || $todo == 'list' || $todo == 'det') {
  $result = $sql_object->DBSelect($req_quickbox_listmod);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_theme_title = formatText(cutText($result[$i]['theme_name'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=" . $result[$i]['theme_id'] . "&amp;rub=" . $rub . "&amp;todo=det\" title=\"" . _t('divers','last_modify') . " " . $result[$i]['theme_last_modify_display'] . " - (" . _t('divers','date_crea') . ": " . $result[$i]['theme_date_crea_display'] . ") \">" . $qbx_theme_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('theme','qb_titlemod');
}

if ($todo == 'sup') {
  $result = $sql_object->DBSelect($req_quickbox_listsup);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_theme_title = formatText(cutText($result[$i]['theme_name'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"#\" title=\"" . _t('divers','date_sup') . " " . $result[$i]['theme_last_modify_display'] . " - (" . _t('divers','date_crea') . ": " . $result[$i]['theme_date_crea_display'] . ") \">" . $qbx_theme_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('theme','qb_titlesup');
}

echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
echo "</div>\n";

?>
